@@ -4,7 +4,7 @@ use warnings;
 
 {
     no strict "vars";
-    $VERSION = "1.12";
+    $VERSION = "1.13";
 }
 
 use Acme::CPANAuthors::Register (
@@ -12,11 +12,13 @@ use Acme::CPANAuthors::Register (
     'ADAMK'         => 'Adam Kennedy',
     'AUTRIJUS'      => 'Audrey Tang',
     'BARBIE'        => 'Barbie',
+    'BDFOY'         => 'brian d foy',
     'BINGOS'        => 'Chris Williams',
     'BOBTFISH'      => 'Tomas Doran',
     'DAGOLDEN'      => 'David Golden',
     'DMAKI'         => 'Daisuke Maki',
     'DROLSKY'       => 'Dave Rolsky',
+    'ELIZABETH'     => 'Elizabeth Mattijsen',
     'ETHER'         => 'Karen Etheridge',
     'FAYLAND'       => 'Fayland Lin',
     'FLORA'         => 'Florian Ragwitz',
@@ -25,6 +27,7 @@ use Acme::CPANAuthors::Register (
     'JGNI'          => 'John Imrie',
     'KENTNL'        => 'Kent Fredric',
     'LBROCARD'      => 'Leon Brocard',
+    'MANWAR'        => 'Mohammad S Anwar',
     'MARCEL'        => '???',
     'MIYAGAWA'      => 'Tatsuhiko Miyagawa',
     'MLEHMANN'      => '???',
@@ -35,6 +38,7 @@ use Acme::CPANAuthors::Register (
     'PEVANS'        => 'Paul Evans',
     'PLICEASE'      => 'Graham Ollis',
     'PSIXDISTS'     => 'Perl 6 Modules',
+    'RENEEB'        => 'Renee Baecker',
     'RJBS'          => 'Ricardo SIGNES',
     'RSAVAGE'       => 'Ron Savage',
     'SALVA'         => 'Salvador Fandino Garcia',
@@ -42,8 +46,10 @@ use Acme::CPANAuthors::Register (
     'SIMON'         => 'Simon Cozens',
     'SKIM'          => 'Michal Josef Spacek',
     'SMUELLER'      => 'Steffen Mueller',
+    'TEAM'          => 'Tom Molesworth',
     'TOBYINK'       => 'Toby Inkster',
     'TOKUHIROM'     => '???',
+    'YANICK'        => 'Yanick Champoux',
 
 );
 
@@ -76,43 +82,49 @@ currently maintaining 100 or more distributions on CPAN.
 
 =head1 THE AUTHORS
 
-   1.  1153  PERLANCAR     perlancar
-   2.  549  PSIXDISTS     Perl 6 Modules
-   3.  295  RJBS          Ricardo SIGNES
-   4.  267  TOBYINK       Toby Inkster
-   5.  247  ADAMK         Adam Kennedy
-   6.  235  MIYAGAWA      Tatsuhiko Miyagawa
-   7.  233  ETHER         Karen Etheridge
-   8.  230  JGNI          John Imrie
-   9.  216  INGY          Ingy dot Net
-  10.  212  BINGOS        Chris Williams
+   1.  1706  PERLANCAR     perlancar
+   2.  550  PSIXDISTS     Perl 6 Modules
+   3.  296  RJBS          Ricardo SIGNES
+   4.  282  TOBYINK       Toby Inkster
+   5.  261  ETHER         Karen Etheridge
+   6.  247  ADAMK         Adam Kennedy
+   7.  245  JGNI          John Imrie
+   8.  239  MIYAGAWA      Tatsuhiko Miyagawa
+   9.  219  INGY          Ingy dot Net
+  10.  215  BINGOS        Chris Williams
   11.  209  FLORA         Florian Ragwitz
-  12.  185  SMUELLER      Steffen Mueller
-  13.  184  KENTNL        Kent Fredric
-  14.  181  TOKUHIROM     ???
-  15.  178  DAGOLDEN      David Golden
-  16.  158  NUFFIN        Yuval Kogman
-  17.  154  PEVANS        Paul Evans
-  18.  152  BOBTFISH      Tomas Doran
-  19.  152  DROLSKY       Dave Rolsky
-  20.  147  MARCEL        ???
-  21.  140  SKIM          Michal Josef Spacek
-  22.  133  PLICEASE      Graham Ollis
-  23.  129  NEILB         Neil Bowers
-  24.  125  GUGOD         Liu Kang Min
-  25.  122  DMAKI         Daisuke Maki
-  26.  121  SHLOMIF       Shlomi Fish
-  27.  118  SIMON         Simon Cozens
-  28.  117  BARBIE        Barbie
-  29.  116  RSAVAGE       Ron Savage
-  30.  112  AUTRIJUS      Audrey Tang
-  31.  107  SALVA         Salvador Fandino Garcia
-  32.  105  FAYLAND       Fayland Lin
-  33.  104  MLEHMANN      ???
-  34.  104  MRAMBERG      Marcus Ramberg
-  35.  101  LBROCARD      Leon Brocard
+  12.  185  KENTNL        Kent Fredric
+  13.  185  SMUELLER      Steffen Mueller
+  14.  182  TOKUHIROM     ???
+  15.  180  DAGOLDEN      David Golden
+  16.  167  PLICEASE      Graham Ollis
+  17.  166  PEVANS        Paul Evans
+  18.  158  NUFFIN        Yuval Kogman
+  19.  156  DROLSKY       Dave Rolsky
+  20.  152  BOBTFISH      Tomas Doran
+  21.  149  SHLOMIF       Shlomi Fish
+  22.  147  MARCEL        ???
+  23.  143  ELIZABETH     Elizabeth Mattijsen
+  24.  140  SKIM          Michal Josef Spacek
+  25.  133  NEILB         Neil Bowers
+  26.  130  GUGOD         Liu Kang Min
+  27.  122  DMAKI         Daisuke Maki
+  28.  118  SIMON         Simon Cozens
+  29.  117  BARBIE        Barbie
+  30.  117  MANWAR        Mohammad S Anwar
+  31.  117  RSAVAGE       Ron Savage
+  32.  112  AUTRIJUS      Audrey Tang
+  33.  112  SALVA         Salvador Fandino Garcia
+  34.  111  MRAMBERG      Marcus Ramberg
+  35.  109  YANICK        Yanick Champoux
+  36.  108  FAYLAND       Fayland Lin
+  37.  107  MLEHMANN      ???
+  38.  103  BDFOY         brian d foy
+  39.  103  RENEEB        Renee Baecker
+  40.  101  LBROCARD      Leon Brocard
+  41.  100  TEAM          Tom Molesworth
 
-List last updated: 2017-05-23T07:53:26
+List last updated: 2019-04-15T04:53:46
 
 =head1 MAINTENANCE
 
@@ -163,7 +175,7 @@ Thanks to Kenichi Ishigaki for writing C<Acme::CPANAuthors>.
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright 2014-2017 Barbie for Miss Barbell Productions.
+  Copyright 2014-2019 Barbie for Miss Barbell Productions.
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
